pub fn init_mooc_client_with_credentials(
root_url: Url,
client_name: &str,
) -> Result<(MoocClient, Option<Credentials>), LangsError>Expand description
Initializes a MoocClient, using and returning the stored credentials, if any.
pub fn init_mooc_client_with_credentials(
root_url: Url,
client_name: &str,
) -> Result<(MoocClient, Option<Credentials>), LangsError>Initializes a MoocClient, using and returning the stored credentials, if any.