pub fn list_local_tmc_course_exercises(
client_name: &str,
course_slug: &str,
) -> Result<Vec<LocalTmcExercise>, LangsError>Expand description
Returns all of the exercises for the given course.
pub fn list_local_tmc_course_exercises(
client_name: &str,
course_slug: &str,
) -> Result<Vec<LocalTmcExercise>, LangsError>Returns all of the exercises for the given course.