Function move_projects_dir

pub fn move_projects_dir(
    tmc_config: TmcConfig,
    target: PathBuf,
) -> Result<(), LangsError>
Moves the projects directory from its current location to the target, taking all of the contained exercises with it.