pub fn reset_settings(client_name: &str) -> Result<(), LangsError>Expand description
Resets all settings in the config, removing those without a default value.
pub fn reset_settings(client_name: &str) -> Result<(), LangsError>Resets all settings in the config, removing those without a default value.