pub fn update_mooc_exercises(
client: &MoocClient,
projects_dir: &Path,
) -> Result<DownloadOrUpdateMoocCourseExercisesResult, LangsError>Expand description
Updates the mooc exercises in the local projects directory.
pub fn update_mooc_exercises(
client: &MoocClient,
projects_dir: &Path,
) -> Result<DownloadOrUpdateMoocCourseExercisesResult, LangsError>Updates the mooc exercises in the local projects directory.