pub fn update_tmc_exercises(
client: &TestMyCodeClient,
projects_dir: &Path,
) -> Result<DownloadOrUpdateTmcCourseExercisesResult, LangsError>Expand description
Updates the tmc exercises in the local projects directory.
pub fn update_tmc_exercises(
client: &TestMyCodeClient,
projects_dir: &Path,
) -> Result<DownloadOrUpdateTmcCourseExercisesResult, LangsError>Updates the tmc exercises in the local projects directory.