pub struct CombinedCourseData {
pub details: CourseDetails,
pub exercises: Vec<CourseExercise>,
pub settings: CourseData,
}Fields
details: CourseDetailsexercises: Vec<CourseExercise>settings: CourseDataTrait Implementations
Sourceimpl Debug for CombinedCourseData
impl Debug for CombinedCourseData
Sourceimpl<'de> Deserialize<'de> for CombinedCourseData
impl<'de> Deserialize<'de> for CombinedCourseData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CombinedCourseData
impl JsonSchema for CombinedCourseData
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CombinedCourseData
impl RefUnwindSafe for CombinedCourseData
impl Send for CombinedCourseData
impl Sync for CombinedCourseData
impl Unpin for CombinedCourseData
impl UnwindSafe for CombinedCourseData