pub struct LocalMoocExercise {
pub exercise_id: Uuid,
pub exercise_path: PathBuf,
}Expand description
MOOC exercise inside the projects directory.
Fields
exercise_id: Uuidexercise_path: PathBufTrait Implementations
Sourceimpl Debug for LocalMoocExercise
impl Debug for LocalMoocExercise
Sourceimpl<'de> Deserialize<'de> for LocalMoocExercise
impl<'de> Deserialize<'de> for LocalMoocExercise
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LocalMoocExercise
impl JsonSchema for LocalMoocExercise
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LocalMoocExercise
impl RefUnwindSafe for LocalMoocExercise
impl Send for LocalMoocExercise
impl Sync for LocalMoocExercise
impl Unpin for LocalMoocExercise
impl UnwindSafe for LocalMoocExercise