pub struct LocalTmcExercise {
pub exercise_slug: String,
pub exercise_path: PathBuf,
}Expand description
TMC eercise inside the projects directory.
Fields
exercise_slug: Stringexercise_path: PathBufTrait Implementations
Sourceimpl Debug for LocalTmcExercise
impl Debug for LocalTmcExercise
Sourceimpl<'de> Deserialize<'de> for LocalTmcExercise
impl<'de> Deserialize<'de> for LocalTmcExercise
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LocalTmcExercise
impl JsonSchema for LocalTmcExercise
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LocalTmcExercise
impl RefUnwindSafe for LocalTmcExercise
impl Send for LocalTmcExercise
impl Sync for LocalTmcExercise
impl Unpin for LocalTmcExercise
impl UnwindSafe for LocalTmcExercise