pub struct MoocExerciseDownload {
pub id: Uuid,
pub path: PathBuf,
}Fields
id: Uuidpath: PathBufTrait Implementations
Sourceimpl Clone for MoocExerciseDownload
impl Clone for MoocExerciseDownload
Sourcefn clone(&self) -> MoocExerciseDownload
fn clone(&self) -> MoocExerciseDownload
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MoocExerciseDownload
impl Debug for MoocExerciseDownload
Sourceimpl<'de> Deserialize<'de> for MoocExerciseDownload
impl<'de> Deserialize<'de> for MoocExerciseDownload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MoocExerciseDownload
impl JsonSchema for MoocExerciseDownload
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MoocExerciseDownload
impl RefUnwindSafe for MoocExerciseDownload
impl Send for MoocExerciseDownload
impl Sync for MoocExerciseDownload
impl Unpin for MoocExerciseDownload
impl UnwindSafe for MoocExerciseDownload