pub struct TestResult {
pub name: String,
pub successful: bool,
pub points: Vec<String>,
pub message: String,
pub exception: Vec<String>,
}Expand description
The result of a single test case.
Fields
name: Stringsuccessful: boolpoints: Vec<String>List of points that were received from the exercise from passed tests.
message: Stringexception: Vec<String>Trait Implementations
Sourceimpl Debug for TestResult
impl Debug for TestResult
Sourceimpl<'de> Deserialize<'de> for TestResult
impl<'de> Deserialize<'de> for TestResult
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TestResult, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TestResult, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<RTestResult> for TestResult
impl From<RTestResult> for TestResult
Sourcefn from(r_test_result: RTestResult) -> TestResult
fn from(r_test_result: RTestResult) -> TestResult
Converts to this type from the input type.
Sourceimpl JsonSchema for TestResult
impl JsonSchema for TestResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TestResult
impl Serialize for TestResult
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more