pub struct TmcConfig {
pub location: PathBuf,
pub projects_dir: PathBuf,
pub table: Table,
}Expand description
The main configuration file. A separate one is used for each client.
Fields
location: PathBufprojects_dir: PathBuftable: TableImplementations
Sourceimpl TmcConfig
impl TmcConfig
Sourcepub fn load(client_name: &str) -> Result<TmcConfig, LangsError>
pub fn load(client_name: &str) -> Result<TmcConfig, LangsError>
Reads or initialises the config for the given client.
Sourcepub fn load_from(
client_name: &str,
path: PathBuf,
) -> Result<TmcConfig, LangsError>
pub fn load_from( client_name: &str, path: PathBuf, ) -> Result<TmcConfig, LangsError>
Reads or initialises for the client from the given path.
Sourcepub fn get_projects_dir(&self) -> &Path
pub fn get_projects_dir(&self) -> &Path
Returns the projects dir.
Sourcepub fn set_projects_dir(
&mut self,
target: PathBuf,
) -> Result<PathBuf, LangsError>
pub fn set_projects_dir( &mut self, target: PathBuf, ) -> Result<PathBuf, LangsError>
Sets the projects dir. Returns the old projects dir.
Sourcepub fn insert(&mut self, key: String, value: Value) -> Option<Value>
pub fn insert(&mut self, key: String, value: Value) -> Option<Value>
Inserts a value with the given key and value. Returns the old value, if any.
Sourcepub fn remove(&mut self, key: &str) -> Option<Value>
pub fn remove(&mut self, key: &str) -> Option<Value>
Removes the value with the given key. Returns the removed value, if any.
Sourcepub fn save(&mut self) -> Result<(), LangsError>
pub fn save(&mut self) -> Result<(), LangsError>
Saves the config struct to the given path.
pub fn get_location(client_name: &str) -> Result<PathBuf, LangsError>