pub struct TmcExerciseDownload {
pub id: u32,
pub course_slug: String,
pub exercise_slug: String,
pub path: PathBuf,
}Fields
id: u32course_slug: Stringexercise_slug: Stringpath: PathBufTrait Implementations
Sourceimpl Clone for TmcExerciseDownload
impl Clone for TmcExerciseDownload
Sourcefn clone(&self) -> TmcExerciseDownload
fn clone(&self) -> TmcExerciseDownload
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TmcExerciseDownload
impl Debug for TmcExerciseDownload
Sourceimpl<'de> Deserialize<'de> for TmcExerciseDownload
impl<'de> Deserialize<'de> for TmcExerciseDownload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TmcExerciseDownload
impl JsonSchema for TmcExerciseDownload
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TmcExerciseDownload
impl RefUnwindSafe for TmcExerciseDownload
impl Send for TmcExerciseDownload
impl Sync for TmcExerciseDownload
impl Unpin for TmcExerciseDownload
impl UnwindSafe for TmcExerciseDownload