pub struct TmcParams(pub HashMap<ShellString, TmcParam>);Expand description
TmcParams is used to safely construct data for a .tmcparams file, which contains lines in the form of export A=B export C=(D, E, F) the keys and values of the inner hashmap are validated to make sure they are valid as bash variables
Tuple Fields
0: HashMap<ShellString, TmcParam>Implementations