pub fn download_old_submission(
client: &TestMyCodeClient,
exercise_id: u32,
output_path: &Path,
submission_id: u32,
save_old_state: bool,
) -> Result<(), LangsError>Expand description
Downloads the user’s old submission from the server. Resets the exercise at the path before the download. If a submission_url is given, the current state of the exercise is submitted to that URL before the download.